==> iwrite-1.0.1.4.tar.gz: iwrite-1.0.1.4/src/item_common_circle.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_common_circle_h__

#include "item_common_base.h"

extern void
item_common_circle_resize(
  struct geom_ellipse *const            io_circle,
  struct item_resize_event const*const  i_ctx,
  int const                             i_ellipse);

extern void
item_common_circle_draw_grips(
  cairo_t *const                        i_cr,
  struct geom_ellipse const*const       i_circle);

extern void
item_common_circle_draw_hightlight(
  cairo_t *const                        i_cr,
  struct geom_ellipse const*const       i_circle,
  double const                          i_width);

extern void
item_common_circle_in_event(
  enum event_type*const                 o_type,
  struct item_in_event const*const      i_ctx,
  struct geom_ellipse const*const       i_circle);

extern void
item_common_circle_move(
  struct geom_ellipse*const             io_circle,
  struct geom_point const*const         i_event);

#define __item_common_circle_h__
#endif

==> iwrite-3.0.1.0.tar.gz: iwrite-3.0.1.0/src/item_common_circle.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
*/
/*
Copyright (c) 2015, iwrite authors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_common_circle_h__

#include "item_common_base.h"

extern void
item_common_circle_resize(
  struct geom_ellipse *const            io_circle,
  struct item_resize_event const*const  i_ctx,
  int const                             i_ellipse);

extern void
item_common_circle_draw_grips(
  cairo_t *const                        io_cr,
  struct geom_ellipse const*const       i_circle);

extern void
item_common_circle_draw_hightlight(
  cairo_t *const                        i_cr,
  struct geom_ellipse const*const       i_circle,
  double const                          i_width);

extern int
item_common_circle_in_event(
  struct item_in_event const*const      i_ctx,
  cairo_t*                              io_cr,
  struct geom_ellipse const*const       i_circle);

extern void
item_common_circle_move(
  struct geom_ellipse*const             io_circle,
  struct geom_point const*const         i_event);

#define __item_common_circle_h__
#endif
